@@ -5,6 +5,7 @@ from datetime import date, datetime, timezone
 from matplotlib import pyplot as plt
 import pytplot
 from fnmatch import filter as tname_filter
+from time import sleep
 
 from .lineplot import lineplot
 from .specplot import specplot
@@ -24,7 +25,8 @@ def tplot(variables, var_label=None,
                      save_png='', 
                      save_eps='', 
                      save_svg='', 
-                     save_pdf='', 
+                     save_pdf='',
+                     dpi=None,
                      display=True, 
                      fig=None, 
                      axis=None, 
@@ -410,16 +412,16 @@ def tplot(variables, var_label=None,
         return fig, axes
     
     if save_png is not None and save_png != '':
-        plt.savefig(save_png + '.png')
+        plt.savefig(save_png + '.png', dpi=dpi)
 
     if save_eps is not None and save_eps != '':
-        plt.savefig(save_eps + '.eps')
+        plt.savefig(save_eps + '.eps', dpi=dpi)
 
     if save_svg is not None and save_svg != '':
-        plt.savefig(save_svg + '.svg')
+        plt.savefig(save_svg + '.svg', dpi=dpi)
 
     if save_pdf is not None and save_pdf != '':
-        plt.savefig(save_pdf + '.pdf')
+        plt.savefig(save_pdf + '.pdf', dpi=dpi)
 
     if slice:
         slice_fig, slice_axes = plt.subplots(nrows=1)
@@ -519,10 +521,12 @@ def mouse_move_slice(event, slice_axes, slice_plot):
     slice_axes.set_xlim(yrange)
     slice_axes.set_xscale(xscale)
     slice_axes.set_yscale(yscale)
+
     try:
         plt.draw()
     except ValueError:
         return
+    sleep(0.01)
 
 
 def get_var_label_ticks(var_xr, times):
