@@ -67,6 +67,7 @@ def tplot(name,
           save_eps='', 
           save_svg='', 
           save_pdf='',
+          dpi=None,
           fig=None, 
           axis=None, 
           pseudo_plot_num=None, 
@@ -161,7 +162,8 @@ def tplot(name,
                                save_png=save_png, 
                                save_eps=save_eps, 
                                save_svg=save_svg, 
-                               save_pdf=save_pdf, 
+                               save_pdf=save_pdf,
+                               dpi=dpi,
                                display=display, 
                                fig=fig, 
                                axis=axis,
